@@ -17,6 +17,7 @@ import os
 import random
 import struct
 import time
+from collections.abc import Iterable
 from concurrent import futures
 
 import blosc
@@ -29,6 +30,7 @@ from tqdm import tqdm
 from urllib3.exceptions import IncompleteRead, ProtocolError
 
 from ....common.dltile import Tile
+from ....common.http.service import DefaultClientMixin
 from ...deprecation import deprecate
 from ..service.service import Service
 from .geotiff_utils import make_geotiff
@@ -225,7 +227,7 @@ def _retry(req, headers=None):
         retry_count += 1
 
 
-class Raster(Service):
+class Raster(Service, DefaultClientMixin):
     """
     The Raster API retrieves data from the Descartes Labs Catalog. Direct use of
     the Raster API is not recommended. Consider using the Descartes Labs Scenes API instead.
@@ -254,7 +256,7 @@ class Raster(Service):
     def raster(
         self,
         inputs,
-        bands=None,
+        bands,
         scales=None,
         data_type=None,
         output_format="GTiff",
@@ -276,17 +278,17 @@ class Raster(Service):
         _retry=_retry,
         **pass_through_params,
     ):
-        """Given a list of :class:`Metadata <descarteslabs.client.services.metadata.Metadata>` identifiers,
+        """Given a list of image identifiers,
         retrieve a translated and warped mosaic as an image file.
 
-        :param inputs: List of :class:`Metadata` identifiers.
+        :param inputs: Iterable of image identifiers.
         :param bands: List of requested bands. If the last item in the list is an alpha
             band (with data range `[0, 1]`) it affects rastering of all other bands:
             When rastering multiple images, they are combined image-by-image only where
             each respective image's alpha band is `1` (pixels where the alpha band is not
             `1` are "transparent" in the overlap between images). If a pixel is fully
             masked considering all combined alpha bands it will be `0` in all non-alpha
-            bands. Not specifying bands returns all bands in the product.
+            bands.
         :param scales: List of tuples specifying the scaling to be applied to each band.
             A tuple has 4 elements in the order ``(src_min, src_max, out_min, out_max)``,
             meaning values in the source range ``src_min`` to ``src_max`` will be scaled
@@ -380,7 +382,7 @@ class Raster(Service):
             chunk_iter = yield_chunks(blosc_meta, r.raw, progress, nodata)
 
             if "id" not in metadata:
-                metadata["id"] = inputs[0]
+                metadata["id"] = params["ids"][0]
 
             try:
                 if output_format == "GTiff":
@@ -418,7 +420,7 @@ class Raster(Service):
     def ndarray(
         self,
         inputs,
-        bands=None,
+        bands,
         scales=None,
         data_type=None,
         srs=None,
@@ -442,14 +444,14 @@ class Raster(Service):
     ):
         """Retrieve a raster as a NumPy array.
 
-        :param inputs: List of :class:`Metadata` identifiers.
+        :param inputs: List of image identifiers.
         :param bands: List of requested bands. If the last item in the list is an alpha
             band (with data range `[0, 1]`) it affects rastering of all other bands:
             When rastering multiple images, they are combined image-by-image only where
             each respective image's alpha band is `1` (pixels where the alpha band is not
             `1` are "transparent" in the overlap between images). If a pixel is fully
             masked considering all combined alpha bands it will be `0` in all non-alpha
-            bands. Not specifying bands returns all bands in the product.
+            bands.
         :param scales: List of tuples specifying the scaling to be applied to each band.
             A tuple has 4 elements in the order ``(src_min, src_max, out_min, out_max)``,
             meaning values in the source range ``src_min`` to ``src_max`` will be scaled
@@ -568,7 +570,7 @@ class Raster(Service):
     def stack(
         self,
         inputs,
-        bands=None,
+        bands,
         scales=None,
         data_type="UInt16",
         srs=None,
@@ -596,7 +598,7 @@ class Raster(Service):
         * set ``dltile``, or
         * set [``resolution`` or ``dimensions``], ``srs``, and ``bounds``
 
-        :param inputs: List, or list of lists, of :class:`Metadata` identifiers.
+        :param inputs: Iterable, or Iterable of Iterables, of image identifiers.
             The stack will follow the same order as this list.
             Each element in the list is treated as a separate input to ``raster.ndarray``,
             so if a list of lists is given, each sublist's identifiers will be mosaiced together
@@ -607,7 +609,7 @@ class Raster(Service):
             each respective image's alpha band is `1` (pixels where the alpha band is not
             `1` are "transparent" in the overlap between images). If a pixel is fully
             masked considering all combined alpha bands it will be `0` in all non-alpha
-            bands. Not specifying bands returns all bands in the product.
+            bands.
         :param scales: List of tuples specifying the scaling to be applied to each band.
             A tuple has 4 elements in the order ``(src_min, src_max, out_min, out_max)``,
             meaning values in the source range ``src_min`` to ``src_max`` will be scaled
@@ -661,9 +663,15 @@ class Raster(Service):
               contain useful information about the raster, such as its geotransform matrix and WKT
               of its coordinate system, but there are no guarantees that certain keys will be present.
         """
-        if not isinstance(inputs, (list, tuple)):
+        if isinstance(inputs, str):
+            inputs = list(inputs)
+        if isinstance(inputs, (list, tuple)):
+            pass
+        elif isinstance(inputs, Iterable):
+            inputs = list(inputs)
+        else:
             raise TypeError(
-                "Inputs must be a list or tuple, instead got '{}'".format(type(inputs))
+                "Inputs must be a Iterable, instead got '{}'".format(type(inputs))
             )
 
         if dltile is None:
@@ -764,7 +772,7 @@ class Raster(Service):
             inputs = [inputs]
 
         params = {
-            "ids": inputs,
+            "ids": list(inputs),
             "bands": bands,
             "scales": scales,
             "ot": data_type,
