@@ -1,9 +1,8 @@
-from .retry import Retry, RetryError, truncated_delay_generator, _name_of_func, _wraps
+from .retry import Retry, RetryError, _name_of_func, truncated_delay_generator
 
 __all__ = [
+    "_name_of_func",
     "Retry",
     "RetryError",
     "truncated_delay_generator",
-    "_name_of_func",
-    "_wraps",
 ]
